package com.agri.system.mapper;

import java.util.List;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.agri.system.domain.SysDevOperLog;

/**
 * 设备控制操作日志Mapper接口
 * 
 * @author lld
 * @date 2026-01-29
 */
public interface SysDevOperLogMapper extends BaseMapper<SysDevOperLog>
{
    /**
     * 查询设备控制操作日志
     * 
     * @param id 设备控制操作日志主键
     * @return 设备控制操作日志
     */
    public SysDevOperLog selectSysDevOperLogById(Long id);

    /**
     * 查询设备控制操作日志列表
     * 
     * @param sysDevOperLog 设备控制操作日志
     * @return 设备控制操作日志集合
     */
    public List<SysDevOperLog> selectSysDevOperLogList(SysDevOperLog sysDevOperLog);

    /**
     * 新增设备控制操作日志
     * 
     * @param sysDevOperLog 设备控制操作日志
     * @return 结果
     */
    public int insertSysDevOperLog(SysDevOperLog sysDevOperLog);

    /**
     * 修改设备控制操作日志
     * 
     * @param sysDevOperLog 设备控制操作日志
     * @return 结果
     */
    public int updateSysDevOperLog(SysDevOperLog sysDevOperLog);

    /**
     * 删除设备控制操作日志
     * 
     * @param id 设备控制操作日志主键
     * @return 结果
     */
    public int deleteSysDevOperLogById(Long id);

    /**
     * 批量删除设备控制操作日志
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSysDevOperLogByIds(Long[] ids);
}
